import React from 'react';
import { PropsWithMetadata } from '@highlight-ui/utils-commons';
import { IconColorTokenType } from '@highlight-ui/tokens';
import { AlertStatus } from './types';
export declare type AlertRef = React.Ref<HTMLDivElement>;
export declare type AlertProps = React.PropsWithChildren<PropsWithMetadata<{
    /** Gives the alert an id */
    id?: string;
    /** Allows rendering a ReactNode (a button is intended) below the alert content */
    actions?: React.ReactNode;
    /** Allows providing a custom class name */
    className?: string;
    /** Allows showing a close button */
    enableCloseButton?: boolean;
    /** If true, uses `100%` of its container width */
    fullWidth?: boolean;
    /** Passes a color to the icon */
    iconColor?: IconColorTokenType;
    /** Passes a font family to the icon */
    iconFamily?: 'regular' | 'light' | 'solid';
    /** Passes an icon name to the icon */
    iconName?: string;
    /** Passes a size to the icon */
    iconSize?: number;
    /** Passes a custom class name to the icon */
    iconClassName?: string;
    /** Passes a function to onClick() of the close button  */
    onClickCloseButton?: () => void;
    /** Defines which variant of the Alert to render */
    status: AlertStatus;
}>>;
export declare function AlertWithRef({ actions, children, className, enableCloseButton, fullWidth, iconColor, iconFamily, iconName, iconSize, iconClassName, metadata, onClickCloseButton, status, ...remainingProps }: AlertProps, ref: AlertRef): JSX.Element;
export declare namespace AlertWithRef {
    var displayName: string;
}
declare const Alert: React.ForwardRefExoticComponent<{
    /** Gives the alert an id */
    id?: string | undefined;
    /** Allows rendering a ReactNode (a button is intended) below the alert content */
    actions?: React.ReactNode;
    /** Allows providing a custom class name */
    className?: string | undefined;
    /** Allows showing a close button */
    enableCloseButton?: boolean | undefined;
    /** If true, uses `100%` of its container width */
    fullWidth?: boolean | undefined;
    /** Passes a color to the icon */
    iconColor?: IconColorTokenType | undefined;
    /** Passes a font family to the icon */
    iconFamily?: "regular" | "light" | "solid" | undefined;
    /** Passes an icon name to the icon */
    iconName?: string | undefined;
    /** Passes a size to the icon */
    iconSize?: number | undefined;
    /** Passes a custom class name to the icon */
    iconClassName?: string | undefined;
    /** Passes a function to onClick() of the close button  */
    onClickCloseButton?: (() => void) | undefined;
    /** Defines which variant of the Alert to render */
    status: AlertStatus;
} & {
    metadata?: import("@highlight-ui/utils-commons").ComponentMetadata | undefined;
} & {
    children?: React.ReactNode;
} & React.RefAttributes<HTMLDivElement>>;
export default Alert;
