import React from 'react';
import { PropsWithMetadata } from '@highlight-ui/utils-commons';
import { IconColorToken } from '@highlight-ui/icon';
import { AlertStatus, DeprecatedAlertStatus } from '../types';
export declare type InlineAlertRef = React.Ref<HTMLDivElement>;
declare type PopoverPlacement = 'bottom-end' | 'bottom-start' | 'bottom' | 'left-end' | 'left-start' | 'left' | 'right-end' | 'right-start' | 'right' | 'top-end' | 'top-start' | 'top';
export declare type InlineAlertProps = React.PropsWithChildren<PropsWithMetadata<{
    /** Gives support text followed by the icon */
    children?: React.ReactNode;
    /** Gives content to a popover when clicking on the icon */
    popoverContent?: React.ReactNode;
    /** Specifies the location of where a popover should appear */
    popoverPlacement?: PopoverPlacement;
    /** Defines which variant of the InlineAlert to render */
    status: AlertStatus | DeprecatedAlertStatus;
    /** Passes a color to the icon */
    iconColor?: IconColorToken;
    /** Passes a font family to the icon */
    iconFamily?: 'regular' | 'light' | 'solid';
    /** Passes an icon name to the icon */
    iconName?: string;
    /** Passes a size to the icon */
    iconSize?: number;
    /** Passes a custom class name to the icon */
    iconClassName?: string;
}>>;
export declare function InlineAlertWithRef({ children, metadata, status, iconColor, iconFamily, iconName, iconSize, iconClassName, popoverContent, popoverPlacement, }: InlineAlertProps, ref: InlineAlertRef): JSX.Element;
export declare namespace InlineAlertWithRef {
    var displayName: string;
}
declare const InlineAlert: React.ForwardRefExoticComponent<{
    /** Gives support text followed by the icon */
    children?: React.ReactNode;
    /** Gives content to a popover when clicking on the icon */
    popoverContent?: React.ReactNode;
    /** Specifies the location of where a popover should appear */
    popoverPlacement?: PopoverPlacement | undefined;
    /** Defines which variant of the InlineAlert to render */
    status: AlertStatus | DeprecatedAlertStatus;
    /** Passes a color to the icon */
    iconColor?: import("@highlight-ui/tokens").IconColorTokenType | undefined;
    /** Passes a font family to the icon */
    iconFamily?: "regular" | "light" | "solid" | undefined;
    /** Passes an icon name to the icon */
    iconName?: string | undefined;
    /** Passes a size to the icon */
    iconSize?: number | undefined;
    /** Passes a custom class name to the icon */
    iconClassName?: string | undefined;
} & {
    metadata?: import("@highlight-ui/utils-commons").ComponentMetadata | undefined;
} & {
    children?: React.ReactNode;
} & React.RefAttributes<HTMLDivElement>>;
export default InlineAlert;
