import React, { useState } from 'react';
import classnames from 'classnames';
import { parseMetadata } from '@highlight-ui/utils-commons';
import { Icon } from '@highlight-ui/icon';
import { IconButton } from '@highlight-ui/button';
import { Stack, Inline } from '@highlight-ui/layout';
import { useClickOutside, useForkRef, useAutoPosition } from '@highlight-ui/utils-hooks';
import { GroupedPortal } from '@highlight-ui/utils-portal-manager';

/******************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

var __assign = function () {
  __assign = Object.assign || function __assign(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
      s = arguments[i];
      for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
    }
    return t;
  };
  return __assign.apply(this, arguments);
};
function __rest(s, e) {
  var t = {};
  for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0) t[p] = s[p];
  if (s != null && typeof Object.getOwnPropertySymbols === "function") for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
    if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i])) t[p[i]] = s[p[i]];
  }
  return t;
}
var statusToIconNameMap = {
  highlight: 'info-circle',
  success: 'check-circle',
  warning: 'exclamation-triangle',
  critical: 'exclamation-circle'
};
var statusToIconName = function (status) {
  return statusToIconNameMap[status];
};
var styles$2 = {
  "alert": "Alert-module__rScsAaPN__v7-1-8",
  "alert-highlight": "Alert-module__2QTjEVq8__v7-1-8",
  "alert-success": "Alert-module__xP1LHYht__v7-1-8",
  "alert-warning": "Alert-module__IKBj6MlH__v7-1-8",
  "alert-critical": "Alert-module__3i0wkJlm__v7-1-8",
  "alertFullWidth": "Alert-module__JjRJnmRM__v7-1-8",
  "alertContent": "Alert-module__ts5gfJw1__v7-1-8",
  "topPadding": "Alert-module__D1eHtukU__v7-1-8",
  "icon": "Alert-module__-xWWD5Pd__v7-1-8",
  "alertBodyContainer": "Alert-module__C82f1g--__v7-1-8"
};
function AlertWithRef(_a, ref) {
  var _b, _c;
  var actions = _a.actions,
    children = _a.children,
    className = _a.className,
    _d = _a.enableCloseButton,
    enableCloseButton = _d === void 0 ? false : _d,
    _e = _a.fullWidth,
    fullWidth = _e === void 0 ? false : _e,
    iconColor = _a.iconColor,
    _f = _a.iconFamily,
    iconFamily = _f === void 0 ? 'solid' : _f,
    iconName = _a.iconName,
    _g = _a.iconSize,
    iconSize = _g === void 0 ? 16 : _g,
    iconClassName = _a.iconClassName,
    metadata = _a.metadata,
    onClickCloseButton = _a.onClickCloseButton,
    status = _a.status,
    remainingProps = __rest(_a, ["actions", "children", "className", "enableCloseButton", "fullWidth", "iconColor", "iconFamily", "iconName", "iconSize", "iconClassName", "metadata", "onClickCloseButton", "status"]);
  var statusIconColor = "icon-".concat(status);
  var statusIconName = statusToIconName(status);
  return /*#__PURE__*/React.createElement("div", __assign({
    ref: ref,
    className: classnames(styles$2.alert, styles$2["alert-".concat(status)], (_b = {}, _b[styles$2.alertFullWidth] = fullWidth, _b), className)
  }, remainingProps, parseMetadata(metadata)), /*#__PURE__*/React.createElement(Stack, {
    space: "spacing-4"
  }, /*#__PURE__*/React.createElement(Inline, {
    space: "spacing-4"
  }, /*#__PURE__*/React.createElement(Inline, {
    space: "spacing-1",
    className: classnames(styles$2.alertContent, (_c = {}, _c[styles$2.topPadding] = enableCloseButton, _c))
  }, /*#__PURE__*/React.createElement("span", null, /*#__PURE__*/React.createElement(Icon, {
    className: classnames(styles$2.icon, iconClassName),
    name: iconName !== null && iconName !== void 0 ? iconName : statusIconName,
    color: iconColor !== null && iconColor !== void 0 ? iconColor : statusIconColor,
    size: iconSize,
    type: iconFamily
  })), children && /*#__PURE__*/React.createElement("div", {
    className: classnames(styles$2.alertBodyContainer)
  }, children)), enableCloseButton && /*#__PURE__*/React.createElement(IconButton, {
    onClick: onClickCloseButton,
    type: "button",
    icon: "times",
    "aria-label": "close alert"
  })), actions && /*#__PURE__*/React.createElement("div", null, actions)));
}
AlertWithRef.displayName = 'Alert';
var Alert = /*#__PURE__*/React.forwardRef(AlertWithRef);
var styles$1 = {
  "heading-xsmall": "InlineAlertPopover-module__cpXFJDXJ__v7-1-8",
  "heading-small": "InlineAlertPopover-module__IDbqwgsm__v7-1-8",
  "heading-medium": "InlineAlertPopover-module__UcAjrDHn__v7-1-8",
  "heading-large": "InlineAlertPopover-module__XcIm3Li4__v7-1-8",
  "heading-xlarge": "InlineAlertPopover-module__XZOPhdP7__v7-1-8",
  "heading-2xl": "InlineAlertPopover-module__Own1O-Qn__v7-1-8",
  "body-small": "InlineAlertPopover-module__vIqgkrGw__v7-1-8",
  "body-base": "InlineAlertPopover-module__WrHZdaem__v7-1-8",
  "body-large": "InlineAlertPopover-module__kaLvlwTh__v7-1-8",
  "body-strong-small": "InlineAlertPopover-module__YQ7r0Bw8__v7-1-8",
  "body-strong-base": "InlineAlertPopover-module__dHBy-LIK__v7-1-8",
  "body-strong-large": "InlineAlertPopover-module__cpIKlGZn__v7-1-8",
  "page-heading": "InlineAlertPopover-module__OGG5oOA2__v7-1-8",
  "button": "InlineAlertPopover-module__IWWK6Uyz__v7-1-8",
  "popover": "InlineAlertPopover-module__mIMd-myB__v7-1-8",
  "form-label": "InlineAlertPopover-module__VtxW8ibY__v7-1-8",
  "caption": "InlineAlertPopover-module__RrqjvBon__v7-1-8",
  "text-link-default": "InlineAlertPopover-module__HOvb2PdN__v7-1-8",
  "text-link-hover": "InlineAlertPopover-module__PFwjMEZz__v7-1-8",
  "table-data-regular": "InlineAlertPopover-module__Z6uejiTl__v7-1-8",
  "table-data-bold": "InlineAlertPopover-module__EsIDKfaj__v7-1-8"
};
function InlineAlertPopover(_a, ref) {
  var children = _a.children,
    style = _a.style,
    closeCallback = _a.closeCallback,
    restProps = __rest(_a, ["children", "style", "closeCallback"]);
  var onClickOutsideRef = useClickOutside(closeCallback);
  var listRef = useForkRef([ref, onClickOutsideRef]);
  return /*#__PURE__*/React.createElement("div", __assign({
    style: style,
    className: styles$1.popover,
    ref: listRef
  }, restProps), children);
}
var InlineAlertPopover$1 = /*#__PURE__*/React.forwardRef(InlineAlertPopover);
var styles = {
  "alertContainer": "InlineAlert-module__HIjXIvPW__v7-1-8",
  "cursorPointer": "InlineAlert-module__xaqEN8rz__v7-1-8",
  "icon": "InlineAlert-module__-3i3ylsB__v7-1-8"
};
var normalizeStatus = function (status) {
  switch (status) {
    case 'info':
      return 'highlight';
    case 'danger':
      return 'critical';
    default:
      return status;
  }
};
function InlineAlertWithRef(_a, ref) {
  var _b;
  var children = _a.children,
    metadata = _a.metadata,
    status = _a.status,
    iconColor = _a.iconColor,
    iconFamily = _a.iconFamily,
    iconName = _a.iconName,
    iconSize = _a.iconSize,
    iconClassName = _a.iconClassName,
    popoverContent = _a.popoverContent,
    _c = _a.popoverPlacement,
    popoverPlacement = _c === void 0 ? 'bottom-start' : _c;
  var normalizedStatus = normalizeStatus(status);
  var statusIconColor = "icon-".concat(normalizedStatus);
  var statusIconName = statusToIconName(normalizedStatus);
  var _d = useState(false),
    isPopoverVisible = _d[0],
    setPopoverVisibility = _d[1];
  var _e = useAutoPosition({
      placement: popoverPlacement
    }),
    triggerRef = _e.triggerRef,
    floatRef = _e.floatRef,
    floatStyles = _e.styles;
  return /*#__PURE__*/React.createElement("div", __assign({
    ref: ref,
    className: styles.alertContainer
  }, parseMetadata(metadata)), /*#__PURE__*/React.createElement("div", {
    ref: triggerRef,
    className: classnames((_b = {}, _b[styles.cursorPointer] = popoverContent, _b)),
    onClick: function () {
      if (isPopoverVisible) {
        return;
      }
      setPopoverVisibility(true);
    }
  }, /*#__PURE__*/React.createElement(Inline, {
    space: "spacing-1"
  }, /*#__PURE__*/React.createElement("span", null, /*#__PURE__*/React.createElement(Icon, {
    className: classnames(styles.icon, iconClassName),
    name: iconName !== null && iconName !== void 0 ? iconName : statusIconName,
    color: iconColor !== null && iconColor !== void 0 ? iconColor : statusIconColor,
    size: iconSize !== null && iconSize !== void 0 ? iconSize : 16,
    type: iconFamily !== null && iconFamily !== void 0 ? iconFamily : 'solid'
  })), children && /*#__PURE__*/React.createElement("div", null, children))), popoverContent && isPopoverVisible && /*#__PURE__*/React.createElement(GroupedPortal, null, /*#__PURE__*/React.createElement(InlineAlertPopover$1, {
    closeCallback: function () {
      setPopoverVisibility(false);
    },
    ref: floatRef,
    style: floatStyles
  }, popoverContent)));
}
InlineAlertWithRef.displayName = 'InlineAlert';
var InlineAlert = /*#__PURE__*/React.forwardRef(InlineAlertWithRef);
export { Alert, InlineAlert };
//# sourceMappingURL=index.js.map
